% pwt91_KeyGraphs.m
%
% Some key graphs from the Stanford Big Data Initiative in International Macro
% using the Penn World Tables 9.1
%
% See pwt91read.m for how to read in the data
%
%   Key Graphs:
%     - Average hours worked in select countries
%     - GrowthSince1980: GDP per person relative to US=100 for select countries
%     -

clear all; close all;
diarychad('pwt91_KeyGraphs');

load pwt91
load regions91   % Region assignments
region=region91;
definecolors % Creates some nice colors used in the graphs

disp ' '; disp ' ';
disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%';
disp '%       Average hours worked in a sample of countries';
disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%';
ctys=[USA GBR FRA JPN KOR];

figure(1); figsetup;
plot(years,avh(:,USA),'-','Color',myblue*.8,'LineWidth',4);
plot(years,avh(:,GBR),'-','Color',mygreen,'LineWidth',4);
plot(years,avh(:,FRA),'-','Color',myred,'LineWidth',4);
plot(years,avh(:,JPN),'-','Color',myblue*1.2,'LineWidth',4);
plot(years,avh(:,KOR),'-','Color',mygreen*.8,'LineWidth',4);
chadfig2('Year','Average annual hours worked',1,0);
ax=axis; ax(2)=max(years)+1; axis(ax);
makefigwide;
text(1995,2700,'S. Korea');
text(1960,1780,'U.S.');
text(1990,2120,'Japan');
text(1990,1550,'France');
text(2015,1600,'U.K.');
print PWTHoursWork.eps

% Display data using Chad's command "cshow" based on an old Gauss command
%   cshow(RowNames,Data,fmt,tle)    type "help cshow" for more information
cshow(' ',[years avh(:,ctys)],'%6.0f %8.0f','Years USA GBR FRA JPN KOR');


disp ' '; disp ' ';
disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%';
disp '%                      Growth since 1980';
disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%';

disp ' ';
disp 'Making the graph...';
ctys=[USA CHN IND JPN RUS BRA];

gdp=rgdpo;
ypc=div(rgdpo,pop);       % per capita  
y=div(ypc,ypc(:,USA))*100; % US=100
africa=(region==1) & (~isnan(y(1980-1949,:)'));

yAfr=sum(gdp(:,africa)')'./sum(pop(:,africa)')';
yWEur=sum(gdp(:,westerneurope)')'./sum(pop(:,westerneurope)')';
yAfr=div(yAfr,ypc(:,USA))*100;
yWEur=div(yWEur,ypc(:,USA))*100;

yrs=(1980:2017)';
t=yrs-1949;
lw=4;

figure(2); figsetup;
plot(yrs,log(y(t,USA)),'-','Color',myblue*.9,'LineWidth',lw); 
plot(yrs,log(y(t,CHN)),'-','Color',myred,'LineWidth',lw);
plot(yrs,log(y(t,IND)),'-','Color',mygreen,'LineWidth',lw); 
plot(yrs,log(y(t,JPN)),'-','Color',mygreen,'LineWidth',lw); 
plot(yrs,log(y(t,RUS)),'-','Color',myred*.9,'LineWidth',lw); 
plot(yrs,log(y(t,BRA)),'-','Color',mypurp,'LineWidth',lw);
plot(yrs,log(yWEur(t)),'-','Color',myblue*1.1,'LineWidth',lw);
plot(yrs,log(yAfr(t)),'-','Color',myblue,'LineWidth',lw); 
relabelaxis(log([5 10 20 40 80 100]),'5 10 20 40 80 100','y');
chadfig2('Year','GDP per Person (US=100)',1,0);
text(2010,log(120),'United States'); 
text(1998.5,log(88.5),'Japan'); 
text(1994,log(56),'Western Europe'); 
text(1985,log(23),'Brazil'); 
text(1995.2,log(35),'Russia'); 
text(1998,log(11.5),'China'); 
text(2005,log(8),'India'); 
text(2003,log(3.4),'Sub-Saharan Africa'); 
set(gca,'YGrid','on');
makefigwide;
ax=axis; ax(3)=log(2); ax(4)=log(110); ax(2)=max(years)+1; axis(ax);
print GrowthSince1980.eps




disp ' '; disp ' ';
disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%';
disp '%                      Barro-style Convergence Plots';
disp '%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%';

yr0=1949;
y=y/100;
y0=y(1960-yr0,:)';
y1=y(max(years)-yr0,:)';

ctys=[USA JPN HKG FRA ZAF MEX IND CHN KEN THA VNM BWA ARG ZWE]';
namethese=zeros(length(y0),1);
namethese(ctys)=1;

figure(3); figsetup;
labs=strmat('1/256#1/128# 1/64 # 1/32 # 1/16 #  1/8  #  1/4  #  1/2  #   1   ','#');
plotlog(log(y0),y1,names,labs,10,[],.8,.5,namethese);
relabelaxis(log([1/256 1/128 1/64 1/32 1/16 1/8 1/4 1/2 1]),labs,'x');
ax=axis; ax(1)=log(1/64); ax(3)=log(1/172); ax(4)=log(1.5); axis(ax);
hold on;
gg=[log(1/256) log(1.5)];
plot(gg,gg,'b-','LineWidth',1);
chadfig2('GDP per person (US=1) in 1960','GDP per person (US=1) in 2017',1,0);
makefigwide;
print Levels1960_2017.eps

disp 'Factor poorer than US = 1/income';
cshow(names,[1./y0 1./y1],'%8.1f','1960 2017');


diary off

